"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signSendWait = void 0;
const sdk_definitions_1 = require("@wormhole-foundation/sdk-definitions");
async function signSendWait(chain, xfer, signer) {
    const txHashes = [];
    if (!(0, sdk_definitions_1.isSigner)(signer))
        throw new Error("Invalid signer, not SignAndSendSigner or SignOnlySigner");
    const signSend = async (txns) => {
        if ((0, sdk_definitions_1.isSignAndSendSigner)(signer)) {
            return signer.signAndSend(txns);
        }
        return chain.sendWait(await signer.sign(txns));
    };
    // buffer unsigned transactions as long as they are
    // marked as parallelizable
    let txbuff = [];
    for await (const tx of xfer) {
        txbuff.push(tx);
        if (tx.parallelizable)
            continue;
        // If !parallelizable, sign/send the current buffer
        txHashes.push(...await signSend(txbuff));
        // reset buffer
        txbuff = [];
    }
    if (txbuff.length > 0) {
        txHashes.push(...await signSend(txbuff));
    }
    return txHashes.map((txid) => ({ chain: chain.chain, txid }));
}
exports.signSendWait = signSendWait;
//# sourceMappingURL=common.js.map