import { chains, chainToPlatform, explorerConfigs, finalityThreshold, nativeDecimals, rpcAddress, constMap, circleAPI, blockTime, } from "@wormhole-foundation/sdk-base";
import { getContracts, } from "@wormhole-foundation/sdk-definitions";
export const DEFAULT_TASK_TIMEOUT = 60 * 1000; // 1 minute in milliseconds
export const CIRCLE_RETRY_INTERVAL = 2000;
export const WHSCAN_RETRY_INTERVAL = 2000;
// TODO: add missing chains for each config
function combineConfig(n) {
    const cc = chains
        .map((c) => {
        const platform = chainToPlatform(c);
        return {
            key: c,
            platform,
            network: n,
            finalityThreshold: finalityThreshold.get(n, c) || 0,
            blockTime: blockTime(c),
            contracts: getContracts(n, c),
            nativeTokenDecimals: nativeDecimals.get(platform),
            explorer: explorerConfigs(n, c),
            rpc: rpcAddress(n, c), //TODO the exclamation mark is a lie
        };
    })
        .reduce((acc, curr) => {
        return { ...acc, [curr.key]: curr };
    }, {});
    return cc;
}
// Combine all the configs for each network/chain
const chainConfigMapping = [
    ["Mainnet", combineConfig("Mainnet")],
    ["Testnet", combineConfig("Testnet")],
    ["Devnet", combineConfig("Devnet")],
];
export const chainConfigs = constMap(chainConfigMapping);
export function networkPlatformConfigs(network, platform) {
    return Object.fromEntries(Object.entries(chainConfigs(network)).filter(([_, v]) => {
        return v.platform == platform;
    }));
}
export const CONFIG = {
    Mainnet: {
        api: "https://api.wormholescan.io",
        circleAPI: circleAPI("Mainnet"),
        chains: chainConfigs("Mainnet"),
    },
    Testnet: {
        api: "https://api.testnet.wormholescan.io",
        circleAPI: circleAPI("Testnet"),
        chains: chainConfigs("Testnet"),
    },
    Devnet: {
        api: "http://guardian:7071",
        circleAPI: "",
        chains: chainConfigs("Devnet"),
    },
};
const inNode = typeof process !== 'undefined';
export const DEFAULT_NETWORK = (inNode && process.env.NETWORK) || "Testnet";
//# sourceMappingURL=config.js.map