import { ChainName, PlatformName } from "@wormhole-foundation/sdk-base";
import { CircleAttestation, CircleMessageId, NativeAddress, ProtocolVAA, Signer, TransactionId, TxHash, UniversalAddress, WormholeMessageId } from "@wormhole-foundation/sdk-definitions";
import { CCTPTransferDetails } from "../types";
import { Wormhole } from "../wormhole";
import { AttestationId, TransferState, WormholeTransfer } from "../wormholeTransfer";
export type CCTPVAA<PayloadName extends string> = ProtocolVAA<"CCTP", PayloadName>;
export declare class CCTPTransfer implements WormholeTransfer {
    private readonly wh;
    private state;
    transfer: CCTPTransferDetails;
    txids: TransactionId[];
    circleAttestations?: {
        id: CircleMessageId;
        attestation?: CircleAttestation;
    }[];
    vaas?: {
        id: WormholeMessageId;
        vaa?: CCTPVAA<"TransferRelay">;
    }[];
    private constructor();
    getTransferState(): Promise<TransferState>;
    static from(wh: Wormhole, from: CCTPTransferDetails): Promise<CCTPTransfer>;
    static from(wh: Wormhole, from: WormholeMessageId, timeout?: number): Promise<CCTPTransfer>;
    static from(wh: Wormhole, from: CircleMessageId, timeout?: number): Promise<CCTPTransfer>;
    static from(wh: Wormhole, from: TransactionId, timeout?: number): Promise<CCTPTransfer>;
    private static fromWormholeMessageId;
    private static fromCircleMessageId;
    private static fromTransaction;
    initiateTransfer(signer: Signer): Promise<TxHash[]>;
    private _fetchWormholeAttestation;
    private _fetchCircleAttestation;
    fetchAttestation(timeout?: number): Promise<AttestationId[]>;
    completeTransfer(signer: Signer): Promise<TxHash[]>;
    static getTransferVaa(wh: Wormhole, chain: ChainName, emitter: UniversalAddress | NativeAddress<PlatformName>, sequence: bigint, timeout?: number): Promise<CCTPVAA<"TransferRelay">>;
}
//# sourceMappingURL=cctpTransfer.d.ts.map